/* econ.c
+------------------------------------------------------------------------------
| Abstract:
|    If CLA: treat it as a filename and print basename \t suffix.
|    Else: Get rid of all whitespace. Insert linebreak on non-alnums.
|
| Authorship:
|    Author: Gisle Hannemyr, University of Oslo ( http://hannemyr.com/ )
|    Copyright (c) 2008 Gisle Hannemyr
|    This is free software released under GPL ver. 3.0.
|    License: http://www.gnu.org/licenses/gpl.html
+----------------------------------------------------------------------------*/

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <ctype.h>

#define FALSE       0			/* Boolean FALSE                    */
#define TRUE        !FALSE		/* Boolean TRUE			    */


/*---( main )----------------------------------------------------------------*/

main(int argc, char *argv[])
{
  int ii, cc, inentity, slash;
  char *bname, *suffix, *bogus="bogus";;

  if (argc >= 3) {
    fputs(argv[0], stderr);
    fputs(": Too many arguments.\n", stderr);
    exit(1);
  }

  /* Return suffix */
  if (argc == 2) {
    bname  = argv[1];
    suffix = strrchr(bname, '.');
    if (suffix) {
	*suffix++ = '\000';
    } else {
	suffix=bogus;
    }
    fputs(bname, stdout);
    fputc('\t', stdout);
    fputs(suffix, stdout);
    fputc('\n', stdout);
    exit(0);
  }

  /* Strip ws */
  slash = inentity = FALSE;
  while ((cc = getchar()) != EOF) {
    if ('&' == cc) {
      inentity = TRUE;
    }
    if (32 < cc) {
      fputc(cc, stdout);
      if (!inentity && !isalnum(cc)) {
	fputc('\n', stdout);
      }
    }
    if (inentity && ';' == cc) {
      inentity = FALSE;
    }
  } /* while */
  fputc('\n', stdout);
  exit(0);
}

/* EOF */
